==> npp.2.7.src.zip: PowerEditor/src/WinControls/ColourPicker/WordStyleDlgRes.h <==
/*
this file is part of notepad++
Copyright (C)2003 Don HO < donho@altern.org >

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define IDD_STYLER_DLG	2200

    #define IDC_STYLETYPE_COMBO	(IDD_STYLER_DLG + 1)
    #define IDC_FONT_COMBO		(IDD_STYLER_DLG + 2)
    #define IDC_FONTSIZE_COMBO	(IDD_STYLER_DLG + 3)
    #define IDC_BOLD_CHECK		(IDD_STYLER_DLG + 4)
    #define IDC_ITALIC_CHECK		(IDD_STYLER_DLG + 5)
    #define IDC_FG_STATIC			(IDD_STYLER_DLG + 6)
    #define IDC_BG_STATIC			(IDD_STYLER_DLG + 7)
    #define IDC_FONTNAME_STATIC      (IDD_STYLER_DLG + 8) 
    #define IDC_FONTSIZE_STATIC       (IDD_STYLER_DLG + 9)
    #define IDC_STYLEDEFAULT_WARNING_STATIC (IDD_STYLER_DLG + 10)
    #define IDC_STYLEDESC_STATIC  (IDD_STYLER_DLG + 11)
    #define IDC_COLOURGROUP_STATIC  (IDD_STYLER_DLG + 12)
    #define IDC_FONTGROUP_STATIC  (IDD_STYLER_DLG + 13)
	
	#define IDC_DEF_EXT_STATIC				(IDD_STYLER_DLG + 14)
    #define IDC_DEF_EXT_EDIT					(IDD_STYLER_DLG + 15)
	#define IDC_USER_EXT_STATIC				(IDD_STYLER_DLG + 16)
	#define IDC_USER_EXT_EDIT					(IDD_STYLER_DLG + 17)
	#define IDC_UNDERLINE_CHECK			(IDD_STYLER_DLG + 18)
	#define IDC_DEF_KEYWORDS_STATIC	(IDD_STYLER_DLG + 19)
	#define IDC_DEF_KEYWORDS_EDIT		(IDD_STYLER_DLG + 20)
	#define IDC_USER_KEYWORDS_STATIC	(IDD_STYLER_DLG + 21)
	#define IDC_USER_KEYWORDS_EDIT		(IDD_STYLER_DLG + 22)
	#define IDC_PLUSSYMBOL_STATIC 		(IDD_STYLER_DLG + 23)
	                                                    
# define IDD_GLOBAL_STYLER_DLG	2300
    #define IDC_SAVECLOSE_BUTTON	(IDD_GLOBAL_STYLER_DLG + 1)
    #define IDC_SC_PERCENTAGE_SLIDER     (IDD_GLOBAL_STYLER_DLG + 2)
	#define IDC_SC_TRANSPARENT_CHECK    (IDD_GLOBAL_STYLER_DLG + 3)

==> npp.3.5.src.zip: PowerEditor/src/WinControls/ColourPicker/WordStyleDlgRes.h <==
/*
this file is part of notepad++
Copyright (C)2003 Don HO < donho@altern.org >

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define IDD_STYLER_DLG	2200

    //#define IDC_STYLETYPE_COMBO	(IDD_STYLER_DLG + 1)
    #define IDC_FONT_COMBO		(IDD_STYLER_DLG + 2)
    #define IDC_FONTSIZE_COMBO	(IDD_STYLER_DLG + 3)
    #define IDC_BOLD_CHECK		(IDD_STYLER_DLG + 4)
    #define IDC_ITALIC_CHECK		(IDD_STYLER_DLG + 5)
    #define IDC_FG_STATIC			(IDD_STYLER_DLG + 6)
    #define IDC_BG_STATIC			(IDD_STYLER_DLG + 7)
    #define IDC_FONTNAME_STATIC      (IDD_STYLER_DLG + 8) 
    #define IDC_FONTSIZE_STATIC       (IDD_STYLER_DLG + 9)
    #define IDC_STYLEDEFAULT_WARNING_STATIC (IDD_STYLER_DLG + 10)
    #define IDC_STYLEDESC_STATIC  (IDD_STYLER_DLG + 11)
    #define IDC_COLOURGROUP_STATIC  (IDD_STYLER_DLG + 12)
    #define IDC_FONTGROUP_STATIC  (IDD_STYLER_DLG + 13)
	
	#define IDC_DEF_EXT_STATIC				(IDD_STYLER_DLG + 14)
    #define IDC_DEF_EXT_EDIT					(IDD_STYLER_DLG + 15)
	#define IDC_USER_EXT_STATIC				(IDD_STYLER_DLG + 16)
	#define IDC_USER_EXT_EDIT					(IDD_STYLER_DLG + 17)
	#define IDC_UNDERLINE_CHECK			(IDD_STYLER_DLG + 18)
	#define IDC_DEF_KEYWORDS_STATIC	(IDD_STYLER_DLG + 19)
	#define IDC_DEF_KEYWORDS_EDIT		(IDD_STYLER_DLG + 20)
	#define IDC_USER_KEYWORDS_STATIC	(IDD_STYLER_DLG + 21)
	#define IDC_USER_KEYWORDS_EDIT		(IDD_STYLER_DLG + 22)
	#define IDC_PLUSSYMBOL_STATIC 		(IDD_STYLER_DLG + 23)
	#define IDC_PLUSSYMBOL2_STATIC 		(IDD_STYLER_DLG + 24)
	#define IDC_LANGDESC_STATIC  (IDD_STYLER_DLG + 25)
	                                                    
# define IDD_GLOBAL_STYLER_DLG	2300
    #define IDC_SAVECLOSE_BUTTON	(IDD_GLOBAL_STYLER_DLG + 1)
    #define IDC_SC_PERCENTAGE_SLIDER     (IDD_GLOBAL_STYLER_DLG + 2)
	#define IDC_SC_TRANSPARENT_CHECK    (IDD_GLOBAL_STYLER_DLG + 3)
	#define IDC_LANGUAGES_LIST   (IDD_GLOBAL_STYLER_DLG + 4)
	#define IDC_STYLES_LIST       (IDD_GLOBAL_STYLER_DLG + 5)
